function [w, wv] = Generate_circweights(N,r,c,phi0,stds,fig)
% Generate weights uniformly located on a circle
% N: number of weights
% r: circle radius
% c: center of the circle
% phi0: initial phase
% stds: pertubation variance (only for ploting)
% fig:  indication to plot the weight (0: not to plot, else: plot)

% Jie Chen, Sept. 2013
% dr.jie.chen@ieee.org
% http://www.jie-chen.com

phi = 2*pi/N*[0: N-1] + phi0;
w = [r*cos(phi)+c(1); r*sin(phi)+c(2)];
wv = reshape(w,[],1);

if fig ~= 0
    figure, hold on
    plot(c(1),c(2),'m+','markersize',15,'linewidth',2);
    theta = [0: 0.01: 2*pi];
    if length(stds)==1
        stds = stds*ones(N,1);
    end
    for i = 1 : N
        plot(w(1,i), w(2,i), 'r.', 'markersize', 25);
        if stds(i)~=0
             plot(3*stds(i)*cos(theta)+w(1,i), 3*stds(i)*sin(theta)+w(2,i),'--');
        end
    end
    plot(r*cos(theta)+c(1), r*sin(theta)+c(2), 'k-.');
    
end
title('Weights')











